@@ -120,6 +120,7 @@ class AnsibleInventoryOutput:
 
     def create_ansible_host(self, name):
         """Create host entry for Ansible inventory."""
+        # pylint: disable=too-many-locals
         meta_host, meta_domain = get_host_from_metadata(self._metadata, name)
         db_host = self._db.hosts[name]
 
@@ -184,6 +185,14 @@ class AnsibleInventoryOutput:
                 }
             )
 
+        for key, val in meta_host.items():
+            if key.startswith("meta_"):
+                host_info[key] = val
+
+        ansible_inventory = meta_host.get("ansible_inventory")
+        if isinstance(ansible_inventory, dict):
+            host_info.update(ansible_inventory)
+
         return host_info
 
     def create_inventory(self):
